/*
 * signal.h - signal handling
 *
 * (c) copyright 1987 by the Vrije Universiteit, Amsterdam, The Netherlands.
 * See the copyright notice in the ACK home directory, in the file "Copyright".
 */
/* $Id$ */

#ifndef _SIGNAL_H
#define _SIGNAL_H

#include <unistd.h>

#endif
