/*
 * Raspberry Pi support library for the PDP/11
 * © 2013 David Given
 * This file is redistributable under the terms of the 3-clause BSD license.
 * See the file 'Copying' in the root of the distribution for the full text.
 */

#ifndef _ACK_PLAT_H
#define _ACK_PLAT_H

#define ACKCONF_WANT_EMULATED_TIME 0

#endif
