/*
 * limits.h - implementation limits
 */
/* $Id$ */

#ifndef _ISO646_H
#define _ISO646_H

#define and &&
#define and_eq  &=
#define bitand  &
#define bitor   |
#define compl   ~
#define not !
#define not_eq  !=
#define or  ||
#define or_eq   |=
#define xor ^
#define xor_eq  ^=

#endif
