/* $Source$
 * $State$
 * $Revision$
 */

#ifndef _ACK_PLAT_H
#define _ACK_PLAT_H

#define _POSIX_SOURCE 1
#define ACKCONF_WANT_EMULATED_TIME 0
#define ACKCONF_WANT_STANDARD_O 0
#define ACKCONF_WANT_STANDARD_SIGNALS 0
#define ACKCONF_WANT_STANDARD_LIMITS 0
#define ACKCONF_WANT_SYS_ERRNO_H 1

#endif
