DEFINITION MODULE MathLib0;
(*
  Module:	Some mathematical functions
  From:		"Programming in Modula-2", 3rd, corrected edition, by N. Wirth
  Version:	$Id$

	Exists for compatibility.
	A more elaborate math lib can be found in Mathlib.def
*)

	PROCEDURE sqrt(x : REAL) : REAL;

	PROCEDURE exp(x : REAL) : REAL;

	PROCEDURE ln(x : REAL) : REAL;

	PROCEDURE sin(x : REAL) : REAL;

	PROCEDURE cos(x : REAL) : REAL;

	PROCEDURE arctan(x : REAL) : REAL;

	PROCEDURE real(x : INTEGER) : REAL;

	PROCEDURE entier(x : REAL) : INTEGER;

END MathLib0.
