/*
 * stdarg.h - variable arguments
 *
 * (c) copyright 1987 by the Vrije Universiteit, Amsterdam, The Netherlands.
 * See the copyright notice in the ACK home directory, in the file "Copyright".
 */
/* $Id$ */

#ifndef _STDBOOL_H
#define _STDBOOL_H

typedef int bool;

#define bool    int
#define true    1
#define false   0

#endif
